/* heston.h: header for analytic solution for HESTON's model
 *
 * author: Gunter Winkler (gw) 
 *         gunter.winkler@mathematik.tu-chemnitz.de
 *
 * changes:
 *	gw	2001-08-07	new
 *
 */

#ifndef __INC_HESTON__
#define __INC_HESTON__

// #define DEBUG	1


#include <iostream>
#include <cmath>
#include <complex>

typedef double				DOUBLE;
typedef std::complex<DOUBLE>	heston_complex;

/*
 *  defines
 */

#ifdef DEBUG
#define DEBUG_HESTON(x)	\
		x 
#else
#define DEBUG_HESTON(x)	
#endif

/*
 *	constants
 */

const heston_complex imag = heston_complex(0,1);

/*
 *	types
 */

struct OPTIONDATA {
	DOUBLE	strike;
	DOUBLE	spot;
	DOUBLE	time;		/* time to maturity */
	DOUBLE	putcall;	/* 1 = call, -1 = put */
};

struct MARKETDATA {
	DOUBLE	rd, rf; 	/* (logarithmic) domestic/foreign interest rates */
	DOUBLE	rho, kappa, theta, xi;	/* stochastic volatility parameters */
	DOUBLE	lambda; 	/* price of volatility risk */
};

/*
 *	functions
 */

double	Pj ( const int j,
			 const DOUBLE x,
			 const DOUBLE v,
			 const DOUBLE tau,
			 const DOUBLE logstrike,
			 MARKETDATA market );

double	Heston_Call( const DOUBLE spot,
					 const DOUBLE v,
					 const DOUBLE tau,
					 const DOUBLE strike,
					 MARKETDATA market );
/*
	formula for vanilla call (same as Black-Scholes)
*/

/*********** last line of heston.h **************/
#endif 
